# Detectors

The [solution_name] Detector tool runs one or more detectors to find and extract dependencies from all supported package managers.

Each package manager ecosystem is assigned a detector type. Each detector type may have multiple methods (detectors) used to extract dependencies.

Which detector(s) will run against your project is determined by the [detector search](../runningdetect/detectorcascade.md) process.

## Detector Types, Entry Points, and Detectors

The following table contains details for each Detector type,
entry point, and detector.
Details on these terms is available on the [detector search](../runningdetect/detectorcascade.md) page.

|Detector Type|Entry Point|Detector|Language|Forge|Requirements|Accuracy|
|---|---|---|---|---|---|---|
|**BITBAKE**|||||||
||Bitbake CLI||||||
||| Bitbake CLI |various|YOCTO | Properties: Package names. File: build env script. Executable: bash|HIGH|
|**CARGO**|||||||
||Cargo Lock||||||
||| Cargo Lock |Rust|crates | Files: Cargo.lock, Cargo.toml|HIGH|
|**CARTHAGE**|||||||
||Carthage Lock||||||
||| Carthage Lock |various|GitHub | Files: Cartfile, Cartfile.resolved|HIGH|
|**CLANG**|||||||
||Clang CLI||||||
||| Clang CLI |C or C++|Derived from the Linux distribution. | File: compile_commands.json. Executable: Linux package manager.|HIGH|
|**COCOAPODS**|||||||
||Pod Lock||||||
||| Pod Lock |Objective C|COCOAPODS and NPMJS | Files: Podfile.lock|HIGH|
|**CONAN**|||||||
||Conan 2 CLI||||||
||| Conan 2 CLI |C/C++|conan | Files: conanfile.txt or conanfile.py. Executable: conan (version 2.x)|HIGH|
||| Conan Lock |C/C++|conan | Files: conan.lock.|HIGH|
||| Conan 1 CLI |C/C++|conan | Files: conanfile.txt or conanfile.py. Executable: conan (version 1.x).|HIGH|
||Conan Lock||||||
||| Conan Lock |C/C++|conan | Files: conan.lock.|HIGH|
||| Conan 1 CLI |C/C++|conan | Files: conanfile.txt or conanfile.py. Executable: conan (version 1.x).|HIGH|
||Conan 1 CLI||||||
||| Conan 1 CLI |C/C++|conan | Files: conanfile.txt or conanfile.py. Executable: conan (version 1.x).|HIGH|
|**CONDA**|||||||
||Conda CLI||||||
||| Conda CLI |Python|Anaconda | File: environment.yml. Executable: conda.|HIGH|
|**CPAN**|||||||
||Cpan CLI||||||
||| Cpan CLI |Perl|CPAN | File: Makefile.PL. Executables: cpan, and cpanm.|HIGH|
|**CRAN**|||||||
||Packrat Lock||||||
||| Packrat Lock |R|CRAN | File: packrat.lock.|HIGH|
|**DART**|||||||
||Dart CLI||||||
||| Dart CLI |Dart|Dart | Files: pubspec.yaml, pubspec.lock. Executable: dart, flutter|HIGH|
||| Dart PubSpec Lock |Dart|Dart | Files: pubspec.yaml, pubspec.lock.|HIGH|
||Dart PubSpec Lock||||||
||| Dart PubSpec Lock |Dart|Dart | Files: pubspec.yaml, pubspec.lock.|HIGH|
|**GIT**|||||||
||Git||||||
||| Git |various|N/A | Directory: .git. (Executable: git).|HIGH|
||| Git Parse |various|N/A | Files: .git/config, .git/HEAD, .git/ORIG_HEAD.|HIGH|
||Git Parse||||||
||| Git Parse |various|N/A | Files: .git/config, .git/HEAD, .git/ORIG_HEAD.|HIGH|
|**GO_DEP**|||||||
||GoDep Lock||||||
||| GoDep Lock |Golang|GitHub | File: Gopkg.lock.|HIGH|
|**GO_GRADLE**|||||||
||GoGradle Lock||||||
||| GoGradle Lock |Golang|GitHub | File: gogradle.lock.|HIGH|
|**GO_MOD**|||||||
||GoMod CLI||||||
||| GoMod CLI |Golang|Go Modules | File: go.mod. Executable: go.|HIGH|
|**GO_VENDOR**|||||||
||Go Vendor||||||
||| Go Vendor |Golang|GitHub | File: vendor/vendor.json.|HIGH|
|**GO_VNDR**|||||||
||GoVndr CLI||||||
||| GoVndr CLI |Golang|GitHub | File: vendor.conf.|HIGH|
|**GRADLE**|||||||
||Gradle Native Inspector||||||
||| Gradle Native Inspector |various|Maven Central | File: build.gradle or build.gradle.kts. Executable: gradlew or gradle.|HIGH|
||| Gradle Project Inspector |various|Maven Central | File: build.gradle|LOW|
|**HEX**|||||||
||Rebar CLI||||||
||| Rebar CLI |Erlang|Hex | File: rebar.config. Executable: rebar3.|HIGH|
|**IVY**|||||||
||Ivy Build Parse||||||
||| Ivy Build Parse |various|Maven Central | File: ivy.xml, build.xml.|LOW|
|**LERNA**|||||||
||Lerna CLI||||||
||| Lerna CLI |Node JS|npmjs | File: lerna.json, package.json, Executable: Lerna, and one of the following: package-lock.json, npm-shrinkwrap.json, yarn.lock.|HIGH|
|**MAVEN**|||||||
||Maven CLI||||||
||| Maven CLI |various|Maven Central | File: pom.xml. Executable: mvnw or mvn.|HIGH|
||| Maven Project Inspector |various|Maven Central | File: pom.xml.|LOW|
||Maven Wrapper CLI||||||
||| Maven Wrapper CLI |various|Maven Central | File: pom.groovy. Executable: mvnw or mvn.|HIGH|
||| Maven Project Inspector |various|Maven Central | File: pom.xml.|LOW|
|**NPM**|||||||
||NPM Shrinkwrap||||||
||| NPM Shrinkwrap |Node JS|npmjs | File: npm-shrinkwrap.json. Optionally for better results: package.json also.|HIGH|
||| NPM Package Lock |Node JS|npmjs | File: package-lock.json. Optionally for better results: package.json also.|HIGH|
||| NPM CLI |Node JS|npmjs | Files: node_modules, package.json. Executable: npm.|HIGH|
||| NPM Package Json Parse |Node JS|npmjs | File: package.json.|LOW|
||NPM Package Lock||||||
||| NPM Package Lock |Node JS|npmjs | File: package-lock.json. Optionally for better results: package.json also.|HIGH|
||| NPM CLI |Node JS|npmjs | Files: node_modules, package.json. Executable: npm.|HIGH|
||| NPM Package Json Parse |Node JS|npmjs | File: package.json.|LOW|
||NPM CLI||||||
||| NPM CLI |Node JS|npmjs | Files: node_modules, package.json. Executable: npm.|HIGH|
||| NPM Package Json Parse |Node JS|npmjs | File: package.json.|LOW|
||NPM Package Json Parse||||||
||| NPM Package Json Parse |Node JS|npmjs | File: package.json.|LOW|
|**NUGET**|||||||
||NuGet Solution Native Inspector||||||
||| NuGet Solution Native Inspector |C#|NuGet.org | File: a solution file with a .sln extension.|HIGH|
||| NuGet Project Inspector |C#|NuGet.org | File: a project file with one of the following extensions: .csproj, .sln|LOW|
||NuGet Project Native Inspector||||||
||| NuGet Project Native Inspector |C#|NuGet.org | File: a project file with one of the following extensions: .csproj, .fsproj, .vbproj, .asaproj, .dcproj, .shproj, .ccproj, .sfproj, .njsproj, .vcxproj, .vcproj, .xproj, .pyproj, .hiveproj, .pigproj, .jsproj, .usqlproj, .deployproj, .msbuildproj, .sqlproj, .dbproj, .rproj|HIGH|
||| NuGet Project Inspector |C#|NuGet.org | File: a project file with one of the following extensions: .csproj, .sln|LOW|
|**PACKAGIST**|||||||
||Composer Lock||||||
||| Composer Lock |PHP|Packagist.org | Files: composer.lock, composer.json.|HIGH|
|**PEAR**|||||||
||Pear CLI||||||
||| Pear CLI |PHP|Pear | Files: package.xml. Executable: pear.|HIGH|
|**PIP**|||||||
||Pipenv Lock||||||
||| Pipenv Lock |Python|PyPi | Files: Pipfile or Pipfile.lock. Executables: python or python3, and pipenv.|HIGH|
||| PIP Native Inspector |Python|Pypi | A setup.py file, or one or more requirements.txt files. Executables: python and pip, or python3 and pip3.|HIGH|
||| Pipfile Lock |Python|PyPi | Files: Pipfile, Pipfile.lock|HIGH|
||PIP Native Inspector||||||
||| PIP Native Inspector |Python|Pypi | A setup.py file, or one or more requirements.txt files. Executables: python and pip, or python3 and pip3.|HIGH|
||| Pipfile Lock |Python|PyPi | Files: Pipfile, Pipfile.lock|HIGH|
||Pipfile Lock||||||
||| Pipfile Lock |Python|PyPi | Files: Pipfile, Pipfile.lock|HIGH|
|**PNPM**|||||||
||Pnpm Lock||||||
||| Pnpm Lock |Node JS|npmjs | Files: pnpm-lock.yaml and package.json.|HIGH|
|**POETRY**|||||||
||Poetry Lock||||||
||| Poetry Lock |Python|pypi | Files: Poetry.lock, pyproject.toml|HIGH|
|**RUBYGEMS**|||||||
||Gemfile Lock||||||
||| Gemfile Lock |Ruby|RubyGems | File: Gemfile.lock.|HIGH|
||| Gemspec Parse |Ruby|RubyGems | File: A gemspec file (with .gemspec extension).|LOW|
||Gemspec Parse||||||
||| Gemspec Parse |Ruby|RubyGems | File: A gemspec file (with .gemspec extension).|LOW|
|**SBT**|||||||
||Sbt Native Inspector||||||
||| Sbt Native Inspector |Scala|Maven Central | File: build.sbt. Plugin: Dependency Graph|HIGH|
|**SWIFT**|||||||
||Swift Lock||||||
||| Swift Lock |Swift|Swift.org | File: Package.swift, Package.resolved|HIGH|
||| Swift CLI |Swift|Swift.org | File: Package.swift. Executables: swift.|HIGH|
||Swift CLI||||||
||| Swift CLI |Swift|Swift.org | File: Package.swift. Executables: swift.|HIGH|
|**XCODE**|||||||
||Xcode Workspace Lock||||||
||| Xcode Workspace Lock |Swift|GITHUB | Directory: *.xcworkspace|HIGH|
||| Xcode Project Lock |Swift|GITHUB | Directory: *.xcodeproj, Files: Package.resolved|HIGH|
||Xcode Project Lock||||||
||| Xcode Project Lock |Swift|GITHUB | Directory: *.xcodeproj, Files: Package.resolved|HIGH|
|**YARN**|||||||
||Yarn Lock||||||
||| Yarn Lock |Node JS|npmjs | Files: yarn.lock and package.json.|HIGH|


