# signature\-scanner

## Detect Excluded Directories Search Depth
```
--detect.excluded.directories.search.depth=4
```

Enables you to adjust the depth to which Detect will search when creating signature scanner exclusion patterns\.



|Details||
|---|---|
|Added|7\.0\.0|
|Type|Integer|
|Default Value|4|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Individual File Matching
```
--detect.blackduck.signature.scanner.individual.file.matching=NONE,SOURCE,BINARY,ALL 
```

Users may set this property to indicate what types of files they want to match\. Corresponding Signature Scanner CLI Argument: \-\-individualFileMatching\.



|Details||
|---|---|
|Added|6\.2\.0|
|Type|IndividualFileMatching|
|Default Value|NONE|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|NONE, SOURCE, BINARY, ALL|
|Strict|Yes|

## Reduced Persistence
```
--detect.blackduck.signature.scanner.reduced.persistence=DEFAULT,RETAIN_UNMATCHED,DISCARD_UNMATCHED 
```

Use this value to control how unmatched files from signature scans are stored\. For a full explanation, please refer to <xref href="https://sig\-product\-docs\.synopsys\.com/bundle/bd\-hub/page/ComponentDiscovery/about\_reduced\_persistence\_signature\_scanning\.html" scope="external" outputclass="external" format="html" target="\_blank">about reduced persistence signature scanning\.</xref>



|Details||
|---|---|
|Added|8\.3\.0|
|Type|ReducedPersistence|
|Default Value|DEFAULT|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|DEFAULT, RETAIN\_UNMATCHED, DISCARD\_UNMATCHED|
|Strict|Yes|

## Signature Scanner Arguments
```
--detect.blackduck.signature.scanner.arguments
```

A space\-separated list of additional arguments to use when running the Black Duck signature scanner\.

For example: Suppose you are running in bash on Linux and want to use the signature scanner's ability to read a list of directories to exclude from a file \(using the signature scanner \-\-exclude\-from option\)\. You tell the signature scanner read excluded directories from a file named excludes\.txt in the current working directory with: \-\-detect\.blackduck\.signature\.scanner\.arguments='\-\-exclude\-from \./excludes\.txt'

|Details||
|---|---|
|Added|4\.2\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|`--exclude-from ./excludes.txt`|

## Signature Scanner Copyright Search
```
--detect.blackduck.signature.scanner.copyright.search=false
```

When set to true, user will be able to scan and discover copyright names in Black Duck\. Corresponding Signature Scanner CLI Argument: \-\-copyright\-search\.



|Details||
|---|---|
|Added|6\.4\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Signature Scanner Dry Run
```
--detect.blackduck.signature.scanner.dry.run=false
```

If set to true, the signature scanner results are not uploaded to Black Duck, and the scanner results are written to disk via the Signature Scanner CLI argument: \-\-dryRunWriteDir\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Signature Scanner License Search
```
--detect.blackduck.signature.scanner.license.search=false
```

When set to true, user will be able to scan and discover license names in Black Duck\. Corresponding Signature Scanner CLI Argument: \-\-license\-search\.



|Details||
|---|---|
|Added|6\.2\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Signature Scanner Local Path
```
--detect.blackduck.signature.scanner.local.path
```

To use a local signature scanner, specify the path where the signature scanner was unzipped\. This will likely look similar to 'scan\.cli\-x\.y\.z' and includes the 'bin, icon, jre, and lib' directories of the expanded scan\.cli\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Signature Scanner Target Paths
```
--detect.blackduck.signature.scanner.paths
```

If this property is not set, the signature scanner target path is the source path \(see property detect\.source\.path\)\. If this property is set, the paths provided in this property's value will be signature scanned instead \(the signature scanner will be executed once for each provided path\)\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|Path List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Snippet Matching
```
--detect.blackduck.signature.scanner.snippet.matching=NONE,SNIPPET_MATCHING,SNIPPET_MATCHING_ONLY,FULL_SNIPPET_MATCHING,FULL_SNIPPET_MATCHING_ONLY 
```

Use this value to enable the various snippet scanning modes\. For a full explanation, please refer to the 'Running a component scan using the Signature Scanner command line' section in your Black Duck server's online help\. Corresponding Signature Scanner CLI Arguments: \-\-snippet\-matching, \-\-snippet\-matching\-only, \-\-full\-snippet\-scan\.



|Details||
|---|---|
|Added|5\.5\.0|
|Type|SnippetMatching|
|Default Value|NONE|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|NONE, SNIPPET\_MATCHING, SNIPPET\_MATCHING\_ONLY, FULL\_SNIPPET\_MATCHING, FULL\_SNIPPET\_MATCHING\_ONLY|
|Strict|Yes|
|Deprecated Values| <p>FULL\_SNIPPET\_MATCHING: Is deprecated and will be removed in the next major release</p> <p>FULL\_SNIPPET\_MATCHING\_ONLY: Is deprecated and will be removed in the next major release</p>|
## Upload source mode
```
--detect.blackduck.signature.scanner.upload.source.mode=false
```

If set to true, the signature scanner will, if supported by your Black Duck version, upload source code to Black Duck\. Corresponding Signature Scanner CLI Argument: \-\-upload\-source\.



|Details||
|---|---|
|Added|5\.4\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|


## Signature Scanner Memory (Advanced)
```
--detect.blackduck.signature.scanner.memory=4096
```

The memory for the scanner to use\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|Integer|
|Default Value|4096|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    


